pub struct SimpleReferenceFinder<'a, L: Language> { /* private fields */ }Expand description
A helper to find all references of a name in a tree.
Implementations
Sourceimpl<'a, L: Language> SimpleReferenceFinder<'a, L>
impl<'a, L: Language> SimpleReferenceFinder<'a, L>
Sourcepub fn find(
root: &RedNode<'a, L>,
name: &'a str,
source: &'a str,
uri: impl Into<Arc<str>>,
) -> Vec<Location>
pub fn find( root: &RedNode<'a, L>, name: &'a str, source: &'a str, uri: impl Into<Arc<str>>, ) -> Vec<Location>
Finds all references of the given name in the tree.
Arguments
root- The root node of the syntax tree.name- The name of the symbol to find.source- The source text.uri- The URI of the source file.